<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Texmaker</source>
        <translation>A Texmaker névjegye</translation>
    </message>
</context>
<context>
    <name>AddOptionDialog</name>
    <message>
        <source>New</source>
        <translation>Új</translation>
    </message>
</context>
<context>
    <name>AddTagDialog</name>
    <message>
        <source>Edit User Tags</source>
        <translation type="unfinished">Felhasználói sablonok szerkesztése</translation>
    </message>
    <message>
        <source>Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LaTeX Content</source>
        <translation type="unfinished">LaTeX tartalom</translation>
    </message>
    <message>
        <source>Keyboard Trigger</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ArrayDialog</name>
    <message>
        <source>Num of Rows</source>
        <translation>Sorok száma</translation>
    </message>
    <message>
        <source>Num of Columns</source>
        <translation>Oszlopok száma</translation>
    </message>
    <message>
        <source>Columns Alignment</source>
        <translation>Oszlopok igazítása</translation>
    </message>
    <message>
        <source>Environment</source>
        <translation>Környezet</translation>
    </message>
    <message>
        <source>Quick Array</source>
        <translation>Tömb varázsló</translation>
    </message>
</context>
<context>
    <name>Browser</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Index</source>
        <translation>Tárgymutató</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Configure Texmaker</source>
        <translation>A Texmaker beállítása</translation>
    </message>
    <message>
        <source>Commands (% : filename without extension - @ : line number)</source>
        <translation>Parancsok (% : fájlnév kiterjesztés nélkül - @ : sor száma)</translation>
    </message>
    <message>
        <source>LaTeX</source>
        <translation>LaTeX</translation>
    </message>
    <message>
        <source>dvips</source>
        <translation>dvips</translation>
    </message>
    <message>
        <source>Bibtex</source>
        <translation>Bibtex</translation>
    </message>
    <message>
        <source>Makeindex</source>
        <translation>Makeindex</translation>
    </message>
    <message>
        <source>Dvi Viewer</source>
        <translation>Dvi megjelenítő</translation>
    </message>
    <message>
        <source>PS Viewer</source>
        <translation>PS megjelenítő</translation>
    </message>
    <message>
        <source>PdfLaTeX</source>
        <translation>PdfLaTeX</translation>
    </message>
    <message>
        <source>Dvipdfm</source>
        <translation>Dvipdfm</translation>
    </message>
    <message>
        <source>ps2pdf</source>
        <translation>ps2pdf</translation>
    </message>
    <message>
        <source>Pdf Viewer</source>
        <translation>Pdf megjelenítő</translation>
    </message>
    <message>
        <source>Built-in Viewer</source>
        <translation>Beépített megjelenítő</translation>
    </message>
    <message>
        <source>metapost</source>
        <translation>metapost</translation>
    </message>
    <message>
        <source>ghostscript</source>
        <translation>ghostscript</translation>
    </message>
    <message>
        <source>Asymptote</source>
        <translation>Asymptote</translation>
    </message>
    <message>
        <source>Latexmk</source>
        <translation>Latexmk</translation>
    </message>
    <message>
        <source>External Viewer</source>
        <translation>Külső megjelenítő</translation>
    </message>
    <message>
        <source>Embed</source>
        <translation>Beágyazott</translation>
    </message>
    <message>
        <source>Quick Build Command</source>
        <translation>Gyorsfordítás parancs</translation>
    </message>
    <message>
        <source>LaTeX + dvips + View PS</source>
        <translation>LaTeX + dvips + PS megtekintése</translation>
    </message>
    <message>
        <source>LaTeX + View DVI</source>
        <translation>LaTeX + DVI megtekintése</translation>
    </message>
    <message>
        <source>PdfLaTeX + View PDF</source>
        <translation>PdfLaTeX + PDF megtekintése</translation>
    </message>
    <message>
        <source>LaTeX + dvipdfm + View PDF</source>
        <translation>LaTeX + dvipdfm + PDF megtekintése </translation>
    </message>
    <message>
        <source>LaTeX + dvips + ps2pdf + View PDF</source>
        <translation>LaTeX + dvips + psd2pdf + PDF megtekintése</translation>
    </message>
    <message>
        <source>LaTeX + Asymptote + LaTeX + dvips + View PS</source>
        <translation>LaTeX + Asymptote + LaTeX + dvips + PS megtekintése</translation>
    </message>
    <message>
        <source>PdfLaTeX + Asymptote + PdfLaTeX + View Pdf</source>
        <translation>PdfLaTeX + Asymptote + PdfLaTeX + PDF megtekintése</translation>
    </message>
    <message>
        <source>LatexMk + View PDF</source>
        <translation>LatexMk + PDF megtekintése</translation>
    </message>
    <message>
        <source>User : (% : filename without extension)</source>
        <translation>Egyéni: (% : fájlnév kiterjesztés nélkül)</translation>
    </message>
    <message>
        <source>wizard</source>
        <translation>varázsló</translation>
    </message>
    <message>
        <source>(the commands must be separated by &apos;|&apos;)</source>
        <translation>(a parancsokat &apos;|&apos; jellel kell elválasztani)</translation>
    </message>
    <message>
        <source>Don&apos;t launch a new instance of the viewer if the dvi/ps/pdf file is already opened</source>
        <translation>Ne futassa a megjelenítő új példányát ha a dvi/ps/pdf fájl már meg van nyitva</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>Szerkesztő</translation>
    </message>
    <message>
        <source>Editor Font Family</source>
        <translation>Szerkesztő betűtípusa</translation>
    </message>
    <message>
        <source>Word Wrap</source>
        <translation>Sortörés</translation>
    </message>
    <message>
        <source>Editor Font Size</source>
        <translation>Szerkesztő betűmérete</translation>
    </message>
    <message>
        <source>Completion</source>
        <translation>Kiegészítés</translation>
    </message>
    <message>
        <source>Editor Font Encoding</source>
        <translation>Szerkesztő karakterkódolása</translation>
    </message>
    <message>
        <source>Show Line Numbers</source>
        <translation>Sorok számának mutatása</translation>
    </message>
    <message>
        <source>&quot;Math&quot; color</source>
        <translation type="obsolete">&quot;Matematika&quot; színe</translation>
    </message>
    <message>
        <source>Click here to set this color</source>
        <translation type="obsolete">Kattintson ide a szín beállításához</translation>
    </message>
    <message>
        <source>&quot;Command&quot; color</source>
        <translation type="obsolete">&quot;Parancs&quot; színe</translation>
    </message>
    <message>
        <source>&quot;Keyword&quot; color</source>
        <translation type="obsolete">&quot;Kulcsszó&quot; színe</translation>
    </message>
    <message>
        <source>Spelling dictionary</source>
        <translation>Helyesírás szótára</translation>
    </message>
    <message>
        <source>Inline Spell Checking</source>
        <translation>Helyesírás-ellenőrzés gépelés közben</translation>
    </message>
    <message>
        <source>Inline</source>
        <translation>Gépelés közben</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Gyorsbillentyűk</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Művelet</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Gyorsbillentyű</translation>
    </message>
    <message>
        <source>Get dictionary at: %1</source>
        <translation type="obsolete">Szótár letöltése innen: %1</translation>
    </message>
    <message>
        <source>Commands</source>
        <translation>Parancsok</translation>
    </message>
    <message>
        <source>Quick Build</source>
        <translation>Gyorsfordítás</translation>
    </message>
    <message>
        <source>Browse dictionary</source>
        <translation>Szótár böngészése</translation>
    </message>
    <message>
        <source>Browse program</source>
        <translation>Program böngészése</translation>
    </message>
    <message>
        <source>R Sweave</source>
        <translation>R Sweave</translation>
    </message>
    <message>
        <source>Check for external changes</source>
        <translation>Külső változások ellenőrzése</translation>
    </message>
    <message>
        <source>Backup documents every 10 min</source>
        <translation>Dokumentumok biztonsági mentése 10 percenként</translation>
    </message>
    <message>
        <source>Tab width (num of spaces)</source>
        <translation>Tabulátor szélessége (szóközök száma)</translation>
    </message>
    <message>
        <source>Replace tab with spaces</source>
        <translation>Tabulátor cseréje szóközökre</translation>
    </message>
    <message>
        <source>Toggle focus editor/pdf viewer</source>
        <translation></translation>
    </message>
    <message>
        <source>PushButton</source>
        <translation></translation>
    </message>
    <message>
        <source>Item</source>
        <translation></translation>
    </message>
    <message>
        <source>Color</source>
        <translation></translation>
    </message>
    <message>
        <source>Colors</source>
        <translation></translation>
    </message>
    <message>
        <source>Default Theme</source>
        <translation></translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>EncodingDialog</name>
    <message>
        <source>Texmaker</source>
        <translation>Texmaker</translation>
    </message>
    <message>
        <source>It seems that this file cannot be correctly decoded
with the default encoding setting</source>
        <translation>Úgy tűnik, ezt a fájlt nem lehet helyesen dekódolni
az alapértelmezett kódolási beállítással</translation>
    </message>
    <message>
        <source>Use this encoding :</source>
        <translation>Használja ezt a kódolást :</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <source>Select a File</source>
        <translation>Válasszon egy fáljt</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <source>Form</source>
        <translation>Formula</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Előre</translation>
    </message>
    <message>
        <source>Backward</source>
        <translation>Hátra</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Csak teljes szavak</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>Kis- és nagybetű</translation>
    </message>
    <message>
        <source>Start at Beginning</source>
        <translation>Kezdés az elejétől</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
</context>
<context>
    <name>GotoLineDialog</name>
    <message>
        <source>Goto Line</source>
        <translation type="obsolete">Ugrás a sorhoz</translation>
    </message>
    <message>
        <source>Goto</source>
        <translation type="obsolete">Ugrás</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Bezárás</translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="obsolete">Sor</translation>
    </message>
</context>
<context>
    <name>GotoLineWidget</name>
    <message>
        <source>Form</source>
        <translation>Formula</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Sor</translation>
    </message>
    <message>
        <source>Goto</source>
        <translation>Ugrás</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
</context>
<context>
    <name>GraphicFileChooser</name>
    <message>
        <source>File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Caption</source>
        <translation>Felirat</translation>
    </message>
    <message>
        <source>Above</source>
        <translation>Felül</translation>
    </message>
    <message>
        <source>Below</source>
        <translation>Alul</translation>
    </message>
    <message>
        <source>Placement</source>
        <translation>Elhelyezés</translation>
    </message>
    <message>
        <source>hbtp</source>
        <translation>hbtp</translation>
    </message>
    <message>
        <source>Use &quot;figure&quot; environment</source>
        <translation>&quot;figure&quot; környezet használata</translation>
    </message>
    <message>
        <source>Select a File</source>
        <translation>Válasszon egy fájlt</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="unfinished">Középre</translation>
    </message>
</context>
<context>
    <name>KeySequenceDialog</name>
    <message>
        <source>Shortcut</source>
        <translation>Gyorsbillentyű</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>LatexEditor</name>
    <message>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Újra</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Kivágás</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Mind kijelölése</translation>
    </message>
    <message>
        <source>Check Spelling Word</source>
        <translation>Szó helyesírás-ellenőrzése</translation>
    </message>
    <message>
        <source>Check Spelling Selection</source>
        <translation>Kijelölés helyesírás-ellenőrzése</translation>
    </message>
    <message>
        <source>Check Spelling Document</source>
        <translation>Dokumentum helyesírás-ellenőrzése</translation>
    </message>
    <message>
        <source>Jump to the end of this block</source>
        <translation>Ugrás a blokk végére</translation>
    </message>
    <message>
        <source>Jump to pdf</source>
        <translation>Ugrás a pdf-hez</translation>
    </message>
</context>
<context>
    <name>LetterDialog</name>
    <message>
        <source>Typeface Size</source>
        <translation>Betűméret</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>Kódolás</translation>
    </message>
    <message>
        <source>AMS Packages</source>
        <translation>AMS csomagok</translation>
    </message>
    <message>
        <source>Paper Size</source>
        <translation>Papírméret</translation>
    </message>
    <message>
        <source>Quick Letter</source>
        <translation>Levél varázsló</translation>
    </message>
</context>
<context>
    <name>LightLatexEditor</name>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>You do not have read permission to this file.</source>
        <translation>Nincs olvasási jogosultsága a fájlhoz.</translation>
    </message>
    <message>
        <source>Click to jump to the bookmark</source>
        <translation>Ugrás a könyvjelzőhöz</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Goto Line</source>
        <translation>Ugrás a sorhoz</translation>
    </message>
</context>
<context>
    <name>LightLineNumberWidget</name>
    <message>
        <source>Click to add or remove a bookmark</source>
        <translation>Kattintson egy könyvjelző hozzáadásához vagy eltávolításához</translation>
    </message>
</context>
<context>
    <name>LineNumberWidget</name>
    <message>
        <source>Click to add or remove a bookmark</source>
        <translation>Kattintson egy könyvjelző hozzáadásához vagy eltávolításához</translation>
    </message>
</context>
<context>
    <name>PaperDialog</name>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Paper Size</source>
        <translation>Papírméret</translation>
    </message>
    <message>
        <source>Print range</source>
        <translation>Nyomtatandó tartomány</translation>
    </message>
    <message>
        <source>Print all</source>
        <translation>Az összes nyomtatása</translation>
    </message>
    <message>
        <source>Pages from</source>
        <translation>Oldalak ettől</translation>
    </message>
    <message>
        <source>to</source>
        <translation>eddig</translation>
    </message>
</context>
<context>
    <name>PdfDocumentWidget</name>
    <message>
        <source>Click to jump to the line</source>
        <translation>Kattintson az adott sorba ugráshoz</translation>
    </message>
</context>
<context>
    <name>PdfViewer</name>
    <message>
        <source>Structure</source>
        <translation>Szerkezet</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Oldalak</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Szerkeszt</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Nézet</translation>
    </message>
    <message>
        <source>Fit Width</source>
        <translation>Igazítás a szélességhez</translation>
    </message>
    <message>
        <source>Fit Page</source>
        <translation>Igazítás az oldalhoz</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Kicsinyítés</translation>
    </message>
    <message>
        <source>Previous Position</source>
        <translation>Előző pozíció</translation>
    </message>
    <message>
        <source>Next Position</source>
        <translation>Következő pozíció</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>External Viewer</source>
        <translation>Külső megjelenítő</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>File not found</source>
        <translation>A fájl nem található</translation>
    </message>
    <message>
        <source>Page</source>
        <translation>Oldal</translation>
    </message>
    <message>
        <source>Can&apos;t print : the ghostscript command (gswin32c.exe) was not found on your system.</source>
        <translation>Nem sikerült nyomtatni : a ghostscript parancs (gswin32c.exe) nem található a rendszerén.</translation>
    </message>
    <message>
        <source>Check Spelling and Grammar on this page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PdfViewerWidget</name>
    <message>
        <source>Show/Hide Table of contents</source>
        <translation>Tartalomjegyzék mutatása/elrejtése</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>Fit Width</source>
        <translation>Igazítás a szélességhez</translation>
    </message>
    <message>
        <source>Fit Page</source>
        <translation>Igazítás az oldalhoz</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Kicsinyítés</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Previous Position</source>
        <translation>Előző pozíció</translation>
    </message>
    <message>
        <source>Next Position</source>
        <translation>Következő pozíció</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>External Viewer</source>
        <translation>Külső megjelenítő</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>File not found</source>
        <translation>A fájl nem található</translation>
    </message>
    <message>
        <source>Can&apos;t print : the ghostscript command (gswin32c.exe) was not found on your system.</source>
        <translation>Nem sikerült nyomtatni : a ghostscript parancs (gswin32c.exe) nem található a rendszerén.</translation>
    </message>
    <message>
        <source>Check Spelling and Grammar on this page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>unknown</source>
        <translation>ismeretlen</translation>
    </message>
    <message>
        <source>Type 1</source>
        <translation>Type 1</translation>
    </message>
    <message>
        <source>Type 1C</source>
        <translation>Type 1C</translation>
    </message>
    <message>
        <source>Type 3</source>
        <translation>Type 3</translation>
    </message>
    <message>
        <source>TrueType</source>
        <translation>TrueType</translation>
    </message>
    <message>
        <source>CID Type 0</source>
        <translation>CID Type 0</translation>
    </message>
    <message>
        <source>CID Type 0C</source>
        <translation>CID Type 0C</translation>
    </message>
    <message>
        <source>CID TrueType</source>
        <translation>CID TrueType</translation>
    </message>
    <message>
        <source>Type 1C (OpenType)</source>
        <translation>Type 1C (OpenType)</translation>
    </message>
    <message>
        <source>TrueType (OpenType)</source>
        <translation>TrueType (OpenType)</translation>
    </message>
    <message>
        <source>CID Type 0C (OpenType)</source>
        <translation>CID Type 0C (OpenType)</translation>
    </message>
    <message>
        <source>CID TrueType (OpenType)</source>
        <translation>CID TrueType (OpenType)</translation>
    </message>
    <message>
        <source>Bug: unexpected font type. Notify poppler mailing list!</source>
        <translation>Hiba: ismeretlen font. Értesítse a poppler levelezőlistát!</translation>
    </message>
</context>
<context>
    <name>QuickDocumentDialog</name>
    <message>
        <source>Author</source>
        <translation>Szerző</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Document Class</source>
        <translation>Dokumentumosztály</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>AMS Packages</source>
        <translation>AMS csomagok</translation>
    </message>
    <message>
        <source>Typeface Size</source>
        <translation>Betűméret</translation>
    </message>
    <message>
        <source>Paper Size</source>
        <translation>Oldalméret</translation>
    </message>
    <message>
        <source>Other Options</source>
        <translation>Egyéb beállítások</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>Kódolás</translation>
    </message>
    <message>
        <source>makeidx Package</source>
        <translation>makeidx csomag</translation>
    </message>
    <message>
        <source>Quick Start</source>
        <translation>Gyorsindítás</translation>
    </message>
    <message>
        <source>babel Package</source>
        <translation>babel csomag</translation>
    </message>
    <message>
        <source>geometry Package</source>
        <translation>geometry csomag</translation>
    </message>
    <message>
        <source>left=2cm,right=2cm,top=2cm,bottom=2cm</source>
        <translation>bal=2cm,jobb=2cm,felül=2cm,alul=2cm</translation>
    </message>
    <message>
        <source>graphicx Package</source>
        <translation>graphicx csomag</translation>
    </message>
    <message>
        <source>lmodern Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kpfonts Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fourier Package</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RefDialog</name>
    <message>
        <source>Labels</source>
        <translation>Címkék</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace Text</source>
        <translation type="obsolete">Szöveg cseréje</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="obsolete">Csere</translation>
    </message>
    <message>
        <source>Find</source>
        <translation type="obsolete">Keresés</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation type="obsolete">Mindet cseréli</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Bezárás</translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="obsolete">Beállítások</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation type="obsolete">Csak teljes szavak</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation type="obsolete">Kis- és nagybetű</translation>
    </message>
    <message>
        <source>Start at Beginning</source>
        <translation type="obsolete">Kezdés az elejétől</translation>
    </message>
    <message>
        <source>Direction</source>
        <translation type="obsolete">Irány</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation type="obsolete">Előre</translation>
    </message>
    <message>
        <source>Backward</source>
        <translation type="obsolete">Hátra</translation>
    </message>
    <message>
        <source>Replace this occurence ? </source>
        <translation type="obsolete">Cseréli ezt az előfordulást?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Igen</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Nem</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Mégse</translation>
    </message>
</context>
<context>
    <name>ReplaceWidget</name>
    <message>
        <source>Form</source>
        <translation>Formula</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Előre</translation>
    </message>
    <message>
        <source>Backward</source>
        <translation>Hátra</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Csere</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>Mindet cseréli</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Csak teljes szavak</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>Kis- és nagybetű</translation>
    </message>
    <message>
        <source>Start at Beginning</source>
        <translation>Kezdés az elejétől</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>Replace this occurence ? </source>
        <translation>Cseréli ezt az előfordulást?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Igen</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nem</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
</context>
<context>
    <name>ScanDialog</name>
    <message>
        <source>Texmaker</source>
        <translation>Texmaker</translation>
    </message>
    <message>
        <source>In directory :</source>
        <translation></translation>
    </message>
    <message>
        <source>Text :</source>
        <translation></translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Include subdirectories</source>
        <translation></translation>
    </message>
    <message>
        <source>Abort</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
</context>
<context>
    <name>SourceView</name>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Fájl megnyitása</translation>
    </message>
</context>
<context>
    <name>SpellerDialog</name>
    <message>
        <source>Check Spelling</source>
        <translation>Helyesírás-ellenőrzés</translation>
    </message>
    <message>
        <source>Unknown word:</source>
        <translation>Ismeretlen szó:</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Csere</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Csere ezzel:</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Mellőzés</translation>
    </message>
    <message>
        <source>Always ignore</source>
        <translation>Mindig mellőz</translation>
    </message>
    <message>
        <source>Suggested words :</source>
        <translation>Javasolt szavak :</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>Check spelling selection...</source>
        <translation>Kijelölés helyesírás-ellenőrzése...</translation>
    </message>
    <message>
        <source>Check spelling from cursor...</source>
        <translation>Helyesírás-ellenőrzés a kurzortól...</translation>
    </message>
    <message>
        <source>No more misspelled words</source>
        <translation>Nincs több helytelenül írt szó</translation>
    </message>
</context>
<context>
    <name>StructDialog</name>
    <message>
        <source>Structure</source>
        <translation>Szerkezet</translation>
    </message>
    <message>
        <source>Numeration</source>
        <translation>Számozás</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
</context>
<context>
    <name>SymbolListWidget</name>
    <message>
        <source>Add to favorites</source>
        <translation>Hozzáadás a kedvencekhez</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Eltávolítás a kedvencek közül</translation>
    </message>
</context>
<context>
    <name>TabDialog</name>
    <message>
        <source>Horizontal Separator</source>
        <translation type="obsolete">Vízszintes elválasztó</translation>
    </message>
    <message>
        <source>Num of Columns</source>
        <translation>Oszlopok száma</translation>
    </message>
    <message>
        <source>Columns Alignment</source>
        <translation type="obsolete">Oszlopok igazítása</translation>
    </message>
    <message>
        <source>Vertical Separator</source>
        <translation type="obsolete">Függőleges elválasztó</translation>
    </message>
    <message>
        <source>Num of Rows</source>
        <translation>Sorok száma</translation>
    </message>
    <message>
        <source>add a margin with the horizontal line</source>
        <translation type="obsolete">margó hozzáadása a vízszintes vonallal</translation>
    </message>
    <message>
        <source>Quick Tabular</source>
        <translation>Táblázat varázsló</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Oszlopok</translation>
    </message>
    <message>
        <source>Column :</source>
        <translation>Oszlop :</translation>
    </message>
    <message>
        <source>Alignment :</source>
        <translation>Igazítás :</translation>
    </message>
    <message>
        <source>Left Border :</source>
        <translation>Bal szegély :</translation>
    </message>
    <message>
        <source>Apply to all columns</source>
        <translation>Alkalmazás minden oszlopra</translation>
    </message>
    <message>
        <source>Right Border (last column) :</source>
        <translation>Jobb szegély (utolsó oszlop) :</translation>
    </message>
    <message>
        <source>Rows</source>
        <translation>Sorok</translation>
    </message>
    <message>
        <source>Row :</source>
        <translation>Sor :</translation>
    </message>
    <message>
        <source>Top Border</source>
        <translation>Felső szegély</translation>
    </message>
    <message>
        <source>Merge columns :</source>
        <translation>Oszlopok egyesítése :</translation>
    </message>
    <message>
        <source>-&gt;</source>
        <translation>-&gt;</translation>
    </message>
    <message>
        <source>Apply to all rows</source>
        <translation>Alkalmazás minden sorra</translation>
    </message>
    <message>
        <source>Bottom Border (last row)</source>
        <translation>Alsó szegély (utolsó sor)</translation>
    </message>
    <message>
        <source>Add vertical margin for each row</source>
        <translation>Függőleges margó hozzáadása minden sorhoz</translation>
    </message>
</context>
<context>
    <name>TabbingDialog</name>
    <message>
        <source>Spacing</source>
        <translation>Térköz</translation>
    </message>
    <message>
        <source>Num of Rows</source>
        <translation>Sorok száma</translation>
    </message>
    <message>
        <source>Num of Columns</source>
        <translation>Oszlopok száma</translation>
    </message>
    <message>
        <source>Quick Tabbing</source>
        <translation>Tabulátor varázsló</translation>
    </message>
</context>
<context>
    <name>TexdocDialog</name>
    <message>
        <source>Search documentation about :</source>
        <translation></translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Texdoc command :</source>
        <translation></translation>
    </message>
    <message>
        <source>Browse program</source>
        <translation>Program böngészése</translation>
    </message>
</context>
<context>
    <name>Texmaker</name>
    <message>
        <source>Structure</source>
        <translation>Szerkezet</translation>
    </message>
    <message>
        <source>Relation symbols</source>
        <translation>Relációjelek</translation>
    </message>
    <message>
        <source>Arrow symbols</source>
        <translation>Nyilak</translation>
    </message>
    <message>
        <source>Miscellaneous symbols</source>
        <translation>Egyéb jelek</translation>
    </message>
    <message>
        <source>Delimiters</source>
        <translation>Határolók</translation>
    </message>
    <message>
        <source>Greek letters</source>
        <translation>Görög betűk</translation>
    </message>
    <message>
        <source>Most used symbols</source>
        <translation>Leggyakrabban használt szimbólumok</translation>
    </message>
    <message>
        <source>Favorites symbols</source>
        <translation>Kedvenc szimbólumok</translation>
    </message>
    <message>
        <source>Pstricks Commands</source>
        <translation>Pstricks parancsok</translation>
    </message>
    <message>
        <source>MetaPost Commands</source>
        <translation>MetaPost parancsok</translation>
    </message>
    <message>
        <source>Tikz Commands</source>
        <translation>Tikz parancsok</translation>
    </message>
    <message>
        <source>Asymptote Commands</source>
        <translation>Asymptote parancsok</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Félkövér</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Dőlt</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="obsolete">Aláhúzott</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Balra</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>Középre</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobbra</translation>
    </message>
    <message>
        <source>New line</source>
        <translation>Új sor</translation>
    </message>
    <message>
        <source>Toggle between the master document and the current document</source>
        <translation>Váltás a fődokumentum és a jelenlegi dokumentum között</translation>
    </message>
    <message>
        <source>Previous Document</source>
        <translation>Előző dokumentum</translation>
    </message>
    <message>
        <source>Next Document</source>
        <translation>Következő dokumetum</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>Click to jump to the bookmark</source>
        <translation>Ugrás a könyvjelzőhöz</translation>
    </message>
    <message>
        <source>Normal Mode</source>
        <translation>Normál mód</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <source>New by copying an existing file</source>
        <translation>Új, egy meglévő fájl másolásával </translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Legutóbbi megnyitása</translation>
    </message>
    <message>
        <source>Restore previous session</source>
        <translation>Előző munkamenet helyreállítása</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Mentés másként</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Összes mentése</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Összes bezárása</translation>
    </message>
    <message>
        <source>Reload document from file</source>
        <translation>Dokumentum újratöltése fájlból</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Szerkesztés</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Újra</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Kivágás</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Mind kijelölése</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Megjegyzésként megjelöl</translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>Megjegyzés törlése </translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>Behúzás növelése</translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>Behúzás csökkentése</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>FindNext</source>
        <translation>Következő keresése</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Csere</translation>
    </message>
    <message>
        <source>Goto Line</source>
        <translation>Ugrás a sorhoz</translation>
    </message>
    <message>
        <source>Check Spelling</source>
        <translation>Helyesírás-ellenőrzés</translation>
    </message>
    <message>
        <source>Refresh Structure</source>
        <translation>Szerkezet frissítése</translation>
    </message>
    <message>
        <source>Refresh Bibliography</source>
        <translation>Irodalomjegyzék frissítése</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Eszközök</translation>
    </message>
    <message>
        <source>Quick Build</source>
        <translation>Gyorsfordítás</translation>
    </message>
    <message>
        <source>View Dvi</source>
        <translation>DVI megtekintése</translation>
    </message>
    <message>
        <source>View PS</source>
        <translation>PS megtekintése</translation>
    </message>
    <message>
        <source>View PDF</source>
        <translation>PDF megtekintése</translation>
    </message>
    <message>
        <source>View Log</source>
        <translation>Napló megtekintése</translation>
    </message>
    <message>
        <source>Clean</source>
        <translation>Takarítás</translation>
    </message>
    <message>
        <source>Previous LaTeX Error</source>
        <translation>Előző LaTeX hiba</translation>
    </message>
    <message>
        <source>Next LaTeX Error</source>
        <translation>Következő LaTeX hiba</translation>
    </message>
    <message>
        <source>&amp;LaTeX</source>
        <translation>&amp;LaTeX</translation>
    </message>
    <message>
        <source>&amp;Sectioning</source>
        <translation>&amp;Szakaszolás</translation>
    </message>
    <message>
        <source>&amp;Environment</source>
        <translation>&amp;Környezet</translation>
    </message>
    <message>
        <source>&amp;List Environment</source>
        <translation>&amp;Listakörnyezet</translation>
    </message>
    <message>
        <source>Font St&amp;yles</source>
        <translation>&amp;Betűstílusok</translation>
    </message>
    <message>
        <source>&amp;Tabular Environment</source>
        <translation>&amp;Táblázatkörnyezet</translation>
    </message>
    <message>
        <source>S&amp;pacing</source>
        <translation>Té&amp;rköz</translation>
    </message>
    <message>
        <source>International &amp;Accents</source>
        <translation>Nemzetközi é&amp;kezetek</translation>
    </message>
    <message>
        <source>&amp;Math</source>
        <translation>&amp;Matematika</translation>
    </message>
    <message>
        <source>Inline math mode $...$</source>
        <translation>Szövegközi matematikai mód $...$</translation>
    </message>
    <message>
        <source>Display math mode \[...\]</source>
        <translation>Kiemelt matematikai mód \[...\]</translation>
    </message>
    <message>
        <source>Numbered equations \begin{equation}</source>
        <translation>Számozott egyenletek \begin{equation}</translation>
    </message>
    <message>
        <source>Math &amp;Functions</source>
        <translation>Matematikai &amp;funkciók</translation>
    </message>
    <message>
        <source>Math Font St&amp;yles</source>
        <translation>Matematikai betűstí&amp;lusok</translation>
    </message>
    <message>
        <source>Math &amp;Accents</source>
        <translation>Matematikai é&amp;kezetek</translation>
    </message>
    <message>
        <source>Math S&amp;paces</source>
        <translation>Matematikai té&amp;rközök</translation>
    </message>
    <message>
        <source>&amp;Wizard</source>
        <translation>&amp;Varázsló</translation>
    </message>
    <message>
        <source>Quick Start</source>
        <translation>Gyorsindítás</translation>
    </message>
    <message>
        <source>Quick Letter</source>
        <translation>Levél varázsló</translation>
    </message>
    <message>
        <source>Quick Tabular</source>
        <translation>Táblázat varázsló</translation>
    </message>
    <message>
        <source>Quick Tabbing</source>
        <translation>Tabulátor varázsló</translation>
    </message>
    <message>
        <source>Quick Array</source>
        <translation>Tömb varázsló</translation>
    </message>
    <message>
        <source>&amp;Bibliography</source>
        <translation>&amp;Irodalomjegyzék</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>Fel&amp;használó</translation>
    </message>
    <message>
        <source>User &amp;Tags</source>
        <translation>Felhasználói &amp;sablonok</translation>
    </message>
    <message>
        <source>Edit User &amp;Tags</source>
        <translation>Felhasználói sa&amp;blonok szerkesztése</translation>
    </message>
    <message>
        <source>User &amp;Commands</source>
        <translation>Felhasználói &amp;parancsok</translation>
    </message>
    <message>
        <source>Edit User &amp;Commands</source>
        <translation>Felhasználói para&amp;ncsok szerkesztése</translation>
    </message>
    <message>
        <source>Customize Completion</source>
        <translation>Kiegészítés testreszabása</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Nézet</translation>
    </message>
    <message>
        <source>Messages / Log File</source>
        <translation>Üzenetek / Naplófájl</translation>
    </message>
    <message>
        <source>Pdf Viewer</source>
        <translation>PDF megjelenítő</translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Beállítások</translation>
    </message>
    <message>
        <source>Configure Texmaker</source>
        <translation>A Texmaker beállítása</translation>
    </message>
    <message>
        <source>Define Current Document as &apos;Master Document&apos;</source>
        <translation>A jelenlegi dokumentum megadása fődokumentumként</translation>
    </message>
    <message>
        <source>Interface Appearance</source>
        <translation>Felület megjelenése</translation>
    </message>
    <message>
        <source>Change Interface Font</source>
        <translation>Felület betűtípusának megváltoztatása</translation>
    </message>
    <message>
        <source>Interface Language</source>
        <translation>Felület nyelve</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Sú&amp;gó</translation>
    </message>
    <message>
        <source>LaTeX Reference</source>
        <translation>LaTeX segédlet</translation>
    </message>
    <message>
        <source>User Manual</source>
        <translation>Felhasználói kézikönyv</translation>
    </message>
    <message>
        <source>About Texmaker</source>
        <translation>A Texmaker névjegye</translation>
    </message>
    <message>
        <source>Run</source>
        <translation>Futtatás</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Nézet</translation>
    </message>
    <message>
        <source>Stop Process</source>
        <translation>Folyamat leállítása</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>You do not have read permission to this file.</source>
        <translation>Nincs olvasási jogosultsága a fájlhoz.</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <source>The document has been changed outside Texmaker.Do you want to reload it (and discard your changes) or save it (and overwrite the file)?</source>
        <translation>A dokumentum a Texmakeren kívül lett módosítva. Újra be kívánja tölteni (ezzel elveszítve a módosításokat) vagy menti (és felülírja a fájlt)? </translation>
    </message>
    <message>
        <source>Reload the file</source>
        <translation>Fájl újratöltése</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>The file could not be saved. Please check if you have write permission.</source>
        <translation>A fájl nem menthető. Ellenőrizze, hogy rendelkezik-e írási jogosultsággal.</translation>
    </message>
    <message>
        <source>The document contains unsaved work. Do you want to save it before closing?</source>
        <translation>A dokumentum nincs elmentve. Menti a bezárás előtt?</translation>
    </message>
    <message>
        <source>Save and Close</source>
        <translation>Mentés és bezárás</translation>
    </message>
    <message>
        <source>Don&apos;t Save and Close</source>
        <translation>Mentés kihagyása és bezárás</translation>
    </message>
    <message>
        <source>The document contains unsaved work. Do you want to save it before exiting?</source>
        <translation>A dokumentum nincs elmentve. Menti a kilépés előtt?</translation>
    </message>
    <message>
        <source>The document contains unsaved work.You will lose changes by reloading the document.</source>
        <translation>A dokumentum nincs elmentve. Ha újratölti, elveszti változtatásait.</translation>
    </message>
    <message>
        <source>Error : Can&apos;t open the dictionary</source>
        <translation>Hiba : A szótárt nem lehet megnyitni</translation>
    </message>
    <message>
        <source>Select an image File</source>
        <translation>Válasszon egy képfájlt</translation>
    </message>
    <message>
        <source>Select a File</source>
        <translation>Válasszon egy fájlt</translation>
    </message>
    <message>
        <source>Can&apos;t detect the file name</source>
        <translation>A fájlnév ismeretlen</translation>
    </message>
    <message>
        <source>Could not start the command.</source>
        <translation>A parancs nem futtatható.</translation>
    </message>
    <message>
        <source>Delete the output files generated by LaTeX ?
(.log,.aux,.dvi,.lof,.lot,.bit,.idx,.glo,.bbl,.ilg,.toc,.ind,.out,.synctex.gz,.blg)</source>
        <translation type="obsolete">Törli a LaTeX által előállított kimeneti fájlokat?
(.log,.aux,.dvi,.lof,.lot,.bit,.idx,.glo,.bbl,.ilg,.toc,.ind,.out,.synctex.gz,.blg)</translation>
    </message>
    <message>
        <source>Delete Files</source>
        <translation>Fájlok törlése</translation>
    </message>
    <message>
        <source>Log File not found !</source>
        <translation>A naplófájl nem található!</translation>
    </message>
    <message>
        <source>Click to jump to the line</source>
        <translation>Kattintson az adott sorba ugráshoz</translation>
    </message>
    <message>
        <source>No LaTeX errors detected !</source>
        <translation>Nem található LaTeX hiba!</translation>
    </message>
    <message>
        <source>File not found</source>
        <translation>A fájl nem található</translation>
    </message>
    <message>
        <source>Normal Mode (current master document :</source>
        <translation>Normál mód (jelenlegi fődokumentum) :</translation>
    </message>
    <message>
        <source>Master Document :</source>
        <translation>Fődokumentum:</translation>
    </message>
    <message>
        <source>The language setting will take effect after restarting the application.</source>
        <translation>Az új nyelvi beállítás az alkalmazás újraindítása után lép életbe.</translation>
    </message>
    <message>
        <source>The appearance setting will take effect after restarting the application.</source>
        <translation>Az új megjelenés az alkalmazás újraindítása után lép életbe.</translation>
    </message>
    <message>
        <source>LaTeX</source>
        <translation>LaTeX</translation>
    </message>
    <message>
        <source>PdfLaTeX</source>
        <translation>PdfLaTeX</translation>
    </message>
    <message>
        <source>dvips</source>
        <translation>dvips</translation>
    </message>
    <message>
        <source>Dvi Viewer</source>
        <translation>Dvi megjelenítő</translation>
    </message>
    <message>
        <source>PS Viewer</source>
        <translation>PS megjelenítő</translation>
    </message>
    <message>
        <source>Dvipdfm</source>
        <translation>Dvipdfm</translation>
    </message>
    <message>
        <source>ps2pdf</source>
        <translation>ps2pdf</translation>
    </message>
    <message>
        <source>Bibtex</source>
        <translation>Bibtex</translation>
    </message>
    <message>
        <source>Makeindex</source>
        <translation>Makeindex</translation>
    </message>
    <message>
        <source>metapost</source>
        <translation>metapost</translation>
    </message>
    <message>
        <source>ghostscript</source>
        <translation>ghostscript</translation>
    </message>
    <message>
        <source>Asymptote</source>
        <translation>Asymptote</translation>
    </message>
    <message>
        <source>Latexmk</source>
        <translation>Latexmk</translation>
    </message>
    <message>
        <source>R Sweave</source>
        <translation>R Sweave</translation>
    </message>
    <message>
        <source>Find In Directory</source>
        <translation></translation>
    </message>
    <message>
        <source>International &amp;Quotes</source>
        <translation></translation>
    </message>
    <message>
        <source>List of opened files</source>
        <translation></translation>
    </message>
    <message>
        <source>Settings File</source>
        <translation></translation>
    </message>
    <message>
        <source>Reset Settings</source>
        <translation></translation>
    </message>
    <message>
        <source>Save a copy of the settings file</source>
        <translation></translation>
    </message>
    <message>
        <source>Replace the settings file by a new one</source>
        <translation></translation>
    </message>
    <message>
        <source>Delete settings file?
(Texmaker will be closed and you will have to restart it)</source>
        <translation></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <source>Replace settings file by a new one?
(Texmaker will be closed and you will have to restart it)</source>
        <translation></translation>
    </message>
    <message>
        <source>Opened Files</source>
        <translation></translation>
    </message>
    <message>
        <source>Delete the output files generated by LaTeX ?
(.log,.aux,.dvi,.lof,.lot,.bit,.idx,.glo,.bbl,.ilg,.toc,.ind,.out,.synctex.gz,.blg,.thm,.pre)</source>
        <translation></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserCompletionDialog</name>
    <message>
        <source>Completion</source>
        <translation>Kiegészítés</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>( @ : placeholder )</source>
        <translation>( @ : helykitöltő )</translation>
    </message>
    <message>
        <source>Items already supplied by Texmaker</source>
        <translation>A Texmaker által felajánlott elemek</translation>
    </message>
    <message>
        <source>( #bib# : bibliography item )</source>
        <translation></translation>
    </message>
    <message>
        <source>( #label# : label item )</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UserMenuDialog</name>
    <message>
        <source>Edit User Tags</source>
        <translation>Felhasználói sablonok szerkesztése</translation>
    </message>
    <message>
        <source>Menu Item</source>
        <translation>Menüelem</translation>
    </message>
    <message>
        <source>LaTeX Content</source>
        <translation>LaTeX tartalom</translation>
    </message>
</context>
<context>
    <name>UserQuickDialog</name>
    <message>
        <source>Quick Build Command</source>
        <translation>Gyorsfordítás parancs</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <source>Ordered list of commands :</source>
        <translation>Parancsok rendezett listája :</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Le</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>UserTagsListWidget</name>
    <message>
        <source>Add tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserToolDialog</name>
    <message>
        <source>Edit User Commands</source>
        <translation>Felhasználói parancs szerkesztése</translation>
    </message>
    <message>
        <source>(the commands must be separated by &apos;|&apos;)</source>
        <translation>(a parancsokat &apos;|&apos; jellel kell elválasztani)</translation>
    </message>
    <message>
        <source>Menu Item</source>
        <translation>Menüelem</translation>
    </message>
    <message>
        <source>Command (% : filename without extension)</source>
        <translation>Parancs (% : fájlnév kiterjesztés nélkül)</translation>
    </message>
    <message>
        <source>wizard</source>
        <translation>varázsló</translation>
    </message>
</context>
<context>
    <name>X11FontDialog</name>
    <message>
        <source>Select a Font</source>
        <translation>Válasszon egy betűtípust</translation>
    </message>
    <message>
        <source>Font Family</source>
        <translation>Betűtípus</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Betűméret</translation>
    </message>
</context>
</TS>
